package com.zhongshu.reward.server.core.controller.wallet;

import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.type.AuthType;
import com.zhongshu.reward.client.model.param.QueryTransferParam;
import com.zhongshu.reward.client.model.param.WalletTransferParam;
import com.zhongshu.reward.server.core.domain.WalletReceipts;
import com.zhongshu.reward.server.core.service.WalletReceiptsService;
import com.zhongshu.reward.server.core.service.WalletService;
import com.zhongshu.reward.server.core.service.WxTransferService;
import io.swagger.annotations.Api;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

/**
 * @author wjf
 * @date 2024/8/5
 */
@Slf4j
@RestController
@RequestMapping("/wallet")
@Api(tags = "钱包")
public class WalletController {

    @Autowired
    WalletService walletService;

    @Autowired
    WxTransferService wxTransferService;

    @Autowired
    WalletReceiptsService walletReceiptsService;

    @Operation(summary = "获取（开通）当前用户钱包信息", description = "获取（开通）当前用户钱包信息")
    @ResourceAuth(value = "user", type = AuthType.User)
    @GetMapping ("getWallet")
    public Object getWalletByUser(){
        return walletService.getWallet();
    }

    @Operation(summary = "发起提现", description = "发起提现")
    @ResourceAuth(value = "user", type = AuthType.User)
    @PostMapping (value = "transfer", consumes = MediaType.APPLICATION_JSON_VALUE)
    public Object transfer(@RequestBody WalletTransferParam param){
        return wxTransferService.transfer(param);
    }


    @Operation(summary = "查询提现列表", description = "查询提现列表")
    @ResourceAuth(value = "user", type = AuthType.User)
    @PostMapping (value = "queryTransfer", consumes = MediaType.APPLICATION_JSON_VALUE)
    public Object queryTransfer(@RequestBody QueryTransferParam param){
        return wxTransferService.queryTransfer(param.getWalletId(), param.getYear(), param.getMonth());
    }

    @Operation(summary = "查询即将到账", description = "查询即将到账")
    @ResourceAuth(value = "user", type = AuthType.User)
    @GetMapping (value = "listByWallet")
    public Object listByWallet(){
        return walletReceiptsService.listByWallet();
    }

    @Operation(summary = "查询即将到账详情", description = "查询即将到账详情")
    @ResourceAuth(value = "user", type = AuthType.User)
    @GetMapping (value = "receiptsDetail")
    public Object receiptsDetail(String receiptsId){
        return walletReceiptsService.receiptsDetail(receiptsId);
    }


}
